@@ -1,4 +1,4 @@
-// Copyright (c) 2015-2020 Jeevanandam M (jeeva@myjeeva.com), All rights reserved.
+// Copyright (c) 2015-2021 Jeevanandam M (jeeva@myjeeva.com), All rights reserved.
 // resty source code and usage is governed by a MIT style
 // license that can be found in the LICENSE file.
 
@@ -48,6 +48,16 @@ func TestGet(t *testing.T) {
 	logResponse(t, resp)
 }
 
+func TestIllegalRetryCount(t *testing.T) {
+	ts := createGetServer(t)
+	defer ts.Close()
+
+	resp, err := dc().SetRetryCount(-1).R().Get(ts.URL + "/")
+
+	assertNil(t, err)
+	assertNil(t, resp)
+}
+
 func TestGetCustomUserAgent(t *testing.T) {
 	ts := createGetServer(t)
 	defer ts.Close()
@@ -1349,6 +1359,18 @@ func TestSetQueryStringTypical(t *testing.T) {
 	assertEqual(t, "TestGet: text response", resp.String())
 }
 
+func TestSetHeaderVerbatim(t *testing.T) {
+	ts := createPostServer(t)
+	defer ts.Close()
+
+	r := dclr().
+		SetHeaderVerbatim("header-lowercase", "value_lowercase").
+		SetHeader("header-lowercase", "value_standard")
+
+	assertEqual(t, "value_lowercase", strings.Join(r.Header["header-lowercase"], "")) //nolint
+	assertEqual(t, "value_standard", r.Header.Get("Header-Lowercase"))
+}
+
 func TestOutputFileWithBaseDirAndRelativePath(t *testing.T) {
 	ts := createGetServer(t)
 	defer ts.Close()
